callthe component from object.
mean.familythe component from object.
dispersion.familythe component from object.
deviancethe component from object.
mean.termsthe component from object.
dispersion.termsthe component from object.
aicthe component from object.
mean.contraststhe component from object.
dispersion.contraststhe component from object.
df.residualthe component from object.
null.deviancethe component from object.
df.nullthe component from object.
information.typethe component from object.
iterthe component from object.
mean.na.actionthe component from object.
dispersion.na.actionthe component from object.
deviance.residthe deviance residuals.
pearson.residthe pearson residuals.
residthe working residuals depends on the setting of deviance.type.
coefficientsthe matrix of coefficients, standard errors, z-values and p-values. Aliased coefficients are omitted.
mean.coefficientsthe matrix of coefficients, standard errors, z-values and p-values of the mean submodel.
dispersion.coefficientsthe matrix of coefficients, standard errors, z-values and p-values of the dispersion submodel.
deviance.typethe type of redidual deviance specified, it is either "deviance" or "pearson".
aliasednamed logical vector showing if the original coefficients are aliased.
dfa 3-vector of the rank of the model and the number of residual degrees of freedom, plus number of coefficients (including aliased ones).
covariancethe estimated covariance matrix of the estimated coefficients.
digitsthe number of significant digits to use when printing.
scientificlogical value of using scientific notation when printing.
covmat.methodnamed method used to invert the covariance matrix.
correlation(only if correlation is true.) The estimated correlations of the estimated coefficients.
symbolic.cor(only if correlation is true.) The value of the argument symbolic.cor.